﻿//
// Copyright (c) 2016, MindFusion LLC - Bulgaria.
//

using System;
using System.Windows.Forms;
using System.Drawing;
using System.Drawing.Drawing2D;


namespace MindFusion.Spreadsheet.WinForms.Samples.CS.Features
{
	public partial class AnnotationsForm : Form
	{
		public AnnotationsForm()
		{
			InitializeComponent();

			var sheet = workbook.Worksheets[0];
			sheet.BeginInit();

			var cell = sheet.Cells[3, 3];
			cell.Data = "Styles";
			cell.SetAnnotation("Annotation with applied styles.");
			var annotation = cell.Annotation.CellAnnotation;
			annotation.ShowAlways = true;
			annotation.AnchorPosition = ObjectAnchorPosition.TopLeft;
			annotation.HorizontalOffset = Measure.Point(-75);
			annotation.VerticalOffset = Measure.Point(-30);
			annotation.Height = Measure.Point(50);
			annotation.BackColor = Color.Navy;
			annotation.TextColor = Color.Gold;
			annotation.LineColor = Color.Gold;
			annotation.Margin = Measure.Point(5);
			annotation.FontBold = true;

			cell = sheet.Cells[4, 3];
			cell.Data = "Default";
			cell.SetAnnotation("Annotation without customizations.");
			annotation = cell.Annotation.CellAnnotation;

			cell = sheet.Cells[4, 4];
			cell.Data = "Fading and animations";
			cell.SetAnnotation("This annotation uses animation and fading.");
			annotation = cell.Annotation.CellAnnotation;
			annotation.AnchorPosition = ObjectAnchorPosition.BottomRight;
			annotation.VerticalOffset = Measure.Point(5);
			annotation.UseAnimation = true;
			annotation.UseFading = true;
			annotation.IndicatorColor = Color.DarkGreen;

			cell = sheet.Cells[3, 4];
			cell.Data = "More styles";
			cell.SetAnnotation("C:\\> echo Hello, world!\r\nHello, world!\r\nC:\\>\u005F");
			annotation = cell.Annotation.CellAnnotation;
			annotation.ShowAlways = true;
			annotation.AnchorPosition = ObjectAnchorPosition.BottomLeft;
			annotation.HorizontalOffset = Measure.Point(-140);
			annotation.VerticalOffset = Measure.Point(5);
			annotation.Width = Measure.Point(135);
			annotation.Height = Measure.Point(40);
			annotation.LineStyle = DashStyle.Dash;
			annotation.LineSize = Measure.Point(1.5);
			annotation.LineColor = Color.Chartreuse;
			annotation.FontName = "Lucida Console";
			annotation.TextColor = Color.Chartreuse;
			annotation.BackColor = Color.Black;
			annotation.FontSize = 9;
			annotation.FontBold = true;
			workbookView.Selection.AddObject(annotation);

			sheet.CellRanges[4, 4, 5, 4].Merge();

			sheet.EndInit();

			workbookView.ActiveCellChanged += new EventHandler(workbookView_ActiveCellChanged);
		}

		void workbookView_ActiveCellChanged(object sender, EventArgs e)
		{
			checkBox.Enabled = workbookView.ActiveCell.Annotation != null;
			if (checkBox.Enabled)
				checkBox.Checked = workbookView.ActiveCell.Annotation.ShowAlways;
		}

		private void button_Click(object sender, EventArgs e)
		{
			var cell = workbookView.ActiveCell;
			if (cell == null)
				return;

			if (cell.Annotation == null)
			{
				// Add a new annotation
				cell.SetAnnotation("New comment.");
				cell.Annotation.ShowAlways = true;
				checkBox.Enabled = true;
				checkBox.Checked = true;
				workbookView.BeginEdit(cell.Annotation);
			}
			else
			{
				// Remove the annotation
				cell.RemoveAnnotation();
			}
		}

		private void checkBox_CheckedChanged(object sender, EventArgs e)
		{
			var cell = workbookView.ActiveCell;
			if (cell == null || cell.Annotation == null)
				return;

			cell.Annotation.ShowAlways = checkBox.Checked;
		}
	}
}
