﻿//
// Copyright (c) 2016, MindFusion LLC - Bulgaria.
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Globalization;

namespace MindFusion.Spreadsheet.WinForms.Samples.CS.Features
{
	public partial class LocalizationForm : Form
	{
		public LocalizationForm()
		{
			InitializeComponent();

			var sheet = workbook.Worksheets[0];

			sheet.BeginInit();

			sheet.Columns[2, 3].Width = Measure.Point(80);
			sheet.Rows[1].Style.FontBold = true;

			sheet.Cells[1, 1].Data = "Type";
			sheet.Cells[2, 1].Data = "Implicit format";
			sheet.Cells[3, 1].Data = "Explicit format";

			sheet.Cells[1, 2].Data = "Integer";
			sheet.Cells[2, 2].Data = 42;
			sheet.Cells[3, 2].Data = 42;
			sheet.Cells[3, 2].Style.Format = "0";

			sheet.Cells[1, 3].Data = "Float";
			sheet.Cells[2, 3].Data = 12.34f;
			sheet.Cells[3, 3].Data = 12.34f;
			sheet.Cells[3, 3].Style.Format = "0.00";

			sheet.Cells[1, 4].Data = "Double";
			sheet.Cells[2, 4].Data = 1234.56;
			sheet.Cells[3, 4].Data = 1234.56;
			sheet.Cells[3, 4].Style.Format = "#,##0.00";

			sheet.Cells[1, 5].Data = "Currency";
			sheet.Cells[2, 5].Data = 15.99.ToString("C");
			sheet.Cells[3, 5].Data = 15.99;
			sheet.Cells[3, 5].Style.Format = workbook.DefaultNumericFormats.CurrencyFormats[1].Format;

			sheet.Cells[1, 6].Data = "Percentage";
			sheet.Cells[2, 6].Data = "75%";
			sheet.Cells[3, 6].Data = 0.75;
			sheet.Cells[3, 6].Style.Format = workbook.DefaultNumericFormats.PercentFormats[1].Format;

			sheet.Cells[1, 7].Data = "Boolean";
			sheet.Cells[2, 7].Data = true;
			sheet.Cells[3, 7].Data = 1;
			sheet.Cells[3, 7].Style.Format = "Boolean";

			sheet.Cells[1, 8].Data = "Date";
			sheet.Cells[2, 8].Data = DateTime.Today;
			sheet.Cells[3, 8].Data = (DateTime.Today - new DateTime(1899, 12, 30)).TotalDays;
			sheet.Cells[3, 8].Style.Format = workbook.DefaultNumericFormats.DateFormats[0].Format;

			var now = DateTime.Now;
			sheet.Cells[1, 9].Data = "Time";
			sheet.Cells[2, 9].Data = new TimeSpan(now.Hour, now.Minute, now.Second);
			sheet.Cells[3, 9].Data = sheet.Cells[2, 9].Data;
			sheet.Cells[3, 9].Style.Format = workbook.DefaultNumericFormats.TimeFormats[1].Format;

			sheet.EndInit();

			var cultures = CultureInfo.GetCultures(CultureTypes.SpecificCultures).Where(ci => !ci.IsNeutralCulture).ToList();
			locale.DataSource = cultures;
			locale.SelectedItem = workbook.Locale;

			locale.SelectedIndexChanged += locale_SelectedIndexChanged;
		}

		private void locale_SelectedIndexChanged(object sender, EventArgs e)
		{
			if (locale.SelectedIndex == -1)
				return;
			workbook.Locale = (CultureInfo)locale.SelectedItem;
		}
	}
}
